<?php

namespace Litecms\Product\Forms;

use Litepie\Form\FormInterpreter;

class Product extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('product/product/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('product/product/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('product/product'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('product/product'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('product/product'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('product/product'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('product::product.label.name'),
                "placeholder" => trans('product::product.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('product::product.label.created_at'),
            'name' => trans('product::product.label.name'),
            'status' => trans('product::product.label.status'),
        ];
        self::$groups = [
            'main' => trans('product::product.groups.main'),
            'details' => trans('product::product.groups.details'),
            'images' => trans('product::product.groups.images'),
            'settings' => trans('product::product.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('product::product.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('product::product.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('product::product.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('product::product.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'name' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.name'),
                "placeholder" => trans('product::product.placeholder.name'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'price' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('product::product.label.price'),
                "placeholder" => trans('product::product.placeholder.price'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'size' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.size'),
                "placeholder" => trans('product::product.placeholder.size'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'external_link' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.external_link'),
                "placeholder" => trans('product::product.placeholder.external_link'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'image' => [
                "element" => 'file',
                "type" => 'image',
                "label" => trans('product::product.label.image'),
                "placeholder" => trans('product::product.placeholder.image'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "12",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'date_published' => [
                "element" => 'date_picker',
                "type" => 'date_picker',
                "label" => trans('product::product.label.date_published'),
                "placeholder" => trans('product::product.placeholder.date_published'),
                "required" => 'true',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'status' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('product::product.label.status'),
                "placeholder" => trans('product::product.placeholder.status'),
                "required" => 'true',
                "options" => function(){
                    return [];
                },
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'category' => [
                "element" => 'model_select',
                "type" => 'model_select',
                "label" => trans('product::product.label.category'),
                "placeholder" => trans('product::product.placeholder.category'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
