<?php

namespace Litecms\Product\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Product\Interfaces\CatalogRepositoryInterface;
use Litecms\Product\Repositories\Eloquent\Filters\CatalogPublicFilter;
use Litecms\Product\Repositories\Eloquent\Presenters\CatalogListPresenter;

class CatalogPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        CatalogRepositoryInterface $catalog
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.product.modules'), 'catalog', guard_url('catalog'));
        $this->repository = $catalog;
    }

    /**
     * Show catalog's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(CatalogPublicFilter::class)
            ->setPresenter(CatalogListPresenter::class)
            ->select('catalogs.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('product::catalog.names'))
            ->view('product::public.catalog.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show catalog.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('product::catalog.name'))
            ->view('product::public.catalog.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
